@@ -24,12 +24,12 @@ def parse_args():
         "genomes",
         metavar="GENOMES",
         type=str,
-        help="a concatenated file containing the sequences you want to search against"
+        help="a concatenated file containing the sequences you want to include in the index"
     )
 
     parser_build.add_argument(
         "taxonomy_tree",
-        metavar="TAX",
+        metavar="NODES",
         type=str,
         help="`\t|\t`-separated file mapping taxonomy IDs to their parents and rank, up to the root of the tree. When using NCBI taxonomy IDs, this will be the `nodes.dmp` from `ftp://ftp.ncbi.nlm.nih.gov/pub/taxonomy/taxdump.tar.gz`."
     )
@@ -43,7 +43,7 @@ def parse_args():
 
     parser_build.add_argument(
         "index_prefix",
-        metavar="IND",
+        metavar="INDEX",
         type=str,
         help="the prefix for the index files that will be generated, will have format: (index_name).1.cf, (index_name).2.cf ..."
     )
@@ -52,7 +52,7 @@ def parse_args():
         "--threads",
         type=int,
         default=os.cpu_count(),
-        help="the number of threads to use when building the index"
+        help="the number of threads to use. This will be passed on to centrifuge-build which will use that many search threads"
     )
 
     parser_build.add_argument(
@@ -71,30 +71,30 @@ def parse_args():
 
     parser_detect.add_argument(
         "contaminated",
-        metavar="CONT",
+        metavar="ASSEMBLY",
         type=str,
-        help=""
+        help=" this is the assembly file, that will be ran against the index to determine its composition"
     )
 
     parser_detect.add_argument(
         "index",
-        metavar="IX",
+        metavar="INDEX",
         type=str,
-        help="the index"
+        help="this is the prefex of the index files that the user wishes to search against"
     )
 
     parser_detect.add_argument(
         "--fragment_length",
         type=int,
         default=150,
-        help="the length of the fragment sequence"
+        help="the length of the fragments"
     )
 
     parser_detect.add_argument(
         "--overlap_length",
         type=int,
         default=0,
-        help="the length of the overlap"
+        help="how much each adjacent fragment will overlap by"
     )
 
 
@@ -102,21 +102,21 @@ def parse_args():
         "--output_file",
         type=str,
         default="result.png",
-        help="the name of the output file that the bar chart will be placed in, will be ignored if graphical output is not specified"
+        help="the name of the output file that the pie chart will be placed in, will be ignored if graphical output is not specified"
     )
 
 
     parser_detect.add_argument(
         "--graphical_output",
         action="store_true",
-        help="output the results as a table, if not specified, the reuslts will be printed as a table"
+        help="output the results as a pie chart, if not specified, the reuslts will be printed as a table"
     )
 
     parser_detect.add_argument(
         "--threads",
         type=int,
         default=os.cpu_count(),
-        help="the number of threads to use when generating the contamination output"
+        help="the number of threads to use. This will be passed on to centrifuge which will use that many search threads"
     )
 
     parser_detect.set_defaults(func=detection)
