@@ -26,7 +26,7 @@ def detect_contamination(args: argparse.Namespace):
 
     exit_now = False
 
-    centrifuge_command = centrifuge_path + " -p " + args.threads + "  -f -x " + args.index + " " + primary_file + " -k 1 " + " --report-file " + summary.name + " >> " + to_write.name
+    centrifuge_command = centrifuge_path + " -p " + str(args.threads) + "  -f -x " + args.index + " " + primary_file + " -k 1 " + " --report-file " + summary.name + " >> " + to_write.name
     new_command = subprocess.run(centrifuge_command, shell=True, capture_output=True)
     if (new_command.returncode != 0):
         exit_now = True
