@@ -40,7 +40,7 @@ def fragmentation(filename,length,overlap,index, path):
                 if tmp == "\n":
                     break
             frag =""
-            previou=""
+            previous=""
             continue;           
         
         #if c is new line ignore
